==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ru.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Общий доступ из федеративного хранилища",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Вы хотите добавить удалённый общий каталог {name} из {owner}@{remote}?",
    "Remote share" : "Удалённый общий ресурс",
    "Remote share password" : "Пароль для удалённого общего ресурса",
    "Cancel" : "Отмена",
    "Add remote share" : "Добавить удалённый общий ресурс",
    "Copy" : "Копировать",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования.",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "Couldn't establish a federated share." : "Не удаётся установить федеративный общий доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не удаётся установить федеративный общий доступ, возможно неверный пароль.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Был отправлен запрос общего федеративного доступа, Вы получите приглашение. Проверьте свои уведомления.",
    "The mountpoint name contains invalid characters." : "Имя точки монтирования содержит недопустимые символы.",
    "Not allowed to create a federated share with the owner." : "Не допускается создание федеративного общего ресурса с владельцем.",
    "Invalid or untrusted SSL certificate" : "Недействительный или недоверенный сертификат SSL",
    "Could not authenticate to remote share, password might be wrong" : "Не удалось провести проверку подлинности для доступа к удалённому хранилищу, возможно неправильно указан пароль",
    "Storage not valid" : "Хранилище недоступно",
    "Federated share added" : "Добавлен общий федеративный ресурс",
    "Couldn't add remote share" : "Невозможно добавить удалённый общий ресурс",
    "Sharing %s failed, because this item is already shared with %s" : "Не удалось поделиться «%s», пользователю%s уже  предоставлен доступ к этому элементу",
    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
    "File is already shared with %s" : "Доступ к файлу уже предоставлен %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Не удалось поделиться «%s», не удалось найти %s, возможно, сервер не доступен или использует само-подписанный сертификат.",
    "Could not find share" : "Не удалось найти общий ресурс",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Вы получили «%3$s»  в качестве удалённого ресурса из %1$s (от имени %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Вы получили «{share}» в качестве удалённого ресурса от {user} (от имени {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Вы получили «%3$s» в качестве удалённого ресурса из %1$s",
    "You received {share} as a remote share from {user}" : "Вы получили «{share}» в качестве удалённого ресурса от {user}",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Поделитесь со мной через мой #Nextcloud ID в федерации облачных хранилищ, смотрите %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поделитесь со мной через мой #Nextcloud ID в федерации облачных хранилищ",
    "Sharing" : "Общий доступ",
    "Federated file sharing" : "Федеративный обмен файлами",
    "Federated Cloud Sharing" : "Федерация облачных хранилищ",
    "Open documentation" : "Открыть документацию",
    "Adjust how people can share between servers." : "Настройте общий доступ между серверами.",
    "Allow users on this server to send shares to other servers" : "Разрешить пользователям делиться с пользователями других серверов",
    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям использовать общие ресурсы с других серверов",
    "Search global and public address book for users" : "Искать пользователей в глобальной и открытой адресной книге",
    "Allow users to publish their data to a global and public address book" : "Резрешить пользователям публиковать свои данные в глобальной и общедосупной адресной книге",
    "Federated Cloud" : "Федерация облачных хранилищ",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можно поделиться с любым пользователем Nextcloud, ownCloud или Pydio! Просто введите его идентификатор  федеративного облачного хранилища в диалоге предоставления общего доступа. Идентификатор указывается в виде «person@cloud.example.com».",
    "Your Federated Cloud ID:" : "Ваш ID в федерации облачных хранилищ:",
    "Share it so your friends can share files with you:" : "Сообщите его друзьям, что бы они могли поделиться с вами файлами:",
    "Add to your website" : "Добавить к себе на сайт",
    "Share with me via Nextcloud" : "Поделитесь со мной через Nextcloud",
    "HTML Code:" : "HTML код:",
    "Search global and public address book for users and let local users publish their data" : "Поиск пользователей в глобальной и общедоступной адресной книге и резрешение публикации своих данных локальным пользователям ",
    "Share it:" : "Поделиться:"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/ru.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Общий доступ из федеративного хранилища",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Вы хотите добавить удалённый общий каталог {name} из {owner}@{remote}?",
    "Remote share" : "Удалённый общий ресурс",
    "Remote share password" : "Пароль для удалённого общего ресурса",
    "Cancel" : "Отмена",
    "Add remote share" : "Добавить удалённый общий ресурс",
    "Copy" : "Копировать",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования.",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Server to server sharing is not enabled on this server" : "На данном сервере выключено межсерверное предоставление общего доступа",
    "Couldn't establish a federated share." : "Не удаётся установить федеративный общий доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не удаётся установить федеративный общий доступ, возможно неверный пароль.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Был отправлен запрос общего федеративного доступа, Вы получите приглашение. Проверьте свои уведомления.",
    "The mountpoint name contains invalid characters." : "Имя точки монтирования содержит недопустимые символы.",
    "Not allowed to create a federated share with the owner." : "Не допускается создание федеративного общего ресурса с владельцем.",
    "Invalid or untrusted SSL certificate" : "Недействительный или недоверенный сертификат SSL",
    "Could not authenticate to remote share, password might be wrong" : "Не удалось провести проверку подлинности для доступа к удалённому хранилищу, возможно неправильно указан пароль",
    "Storage not valid" : "Хранилище недоступно",
    "Federated share added" : "Добавлен общий федеративный ресурс",
    "Couldn't add remote share" : "Невозможно добавить удалённый общий ресурс",
    "Sharing %s failed, because this item is already shared with %s" : "Не удалось поделиться «%s», пользователю%s уже  предоставлен доступ к этому элементу",
    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
    "File is already shared with %s" : "Доступ к файлу уже предоставлен %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Не удалось поделиться «%s», не удалось найти %s, возможно, сервер недоступен или использует самоподписанный сертификат.",
    "Could not find share" : "Не удалось найти общий ресурс",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Вы получили «%3$s»  в качестве удалённого ресурса из %1$s (от имени %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Вы получили «{share}» в качестве удалённого ресурса от {user} (от имени {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Вы получили «%3$s» в качестве удалённого ресурса из %1$s",
    "You received {share} as a remote share from {user}" : "Вы получили {share} в качестве удалённого ресурса от {user}",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Поделитесь со мной через мой #Nextcloud ID в федерации облачных хранилищ, смотрите %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поделитесь со мной через мой #Nextcloud ID в федерации облачных хранилищ",
    "Sharing" : "Общий доступ",
    "Federated Cloud Sharing" : "Федерация облачных хранилищ",
    "Open documentation" : "Открыть документацию",
    "Adjust how people can share between servers." : "Настройте общий доступ между серверами.",
    "Allow users on this server to send shares to other servers" : "Разрешить пользователям делиться с пользователями других серверов",
    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям использовать общие ресурсы с других серверов",
    "Search global and public address book for users" : "Искать пользователей в глобальной и открытой адресной книге",
    "Allow users to publish their data to a global and public address book" : "Разрешить пользователям публиковать свои данные в глобальной и общедоступной адресной книге",
    "Federated Cloud" : "Федерация облачных хранилищ",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можно поделиться с любым пользователем Nextcloud, ownCloud или Pydio! Просто введите его идентификатор  федеративного облачного хранилища в диалоге предоставления общего доступа. Идентификатор указывается в виде «person@cloud.example.com».",
    "Your Federated Cloud ID:" : "Ваш ID в федерации облачных хранилищ:",
    "Share it so your friends can share files with you:" : "Сообщите его друзьям, чтобы они могли поделиться с вами файлами:",
    "Add to your website" : "Добавить к себе на сайт",
    "Share with me via Nextcloud" : "Поделитесь со мной через Nextcloud",
    "HTML Code:" : "HTML код:",
    "Search global and public address book for users and let local users publish their data" : "Поиск пользователей в глобальной и общедоступной адресной книге и разрешение публикации своих данных локальным пользователям ",
    "Share it:" : "Поделиться:"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
